@@ -15,11 +15,6 @@ test_that("prob_vals warnings behave as expected", {
   expect_error(nsec(nec4param, prob_vals = c(0.6, 0.9, 0.1)))
 })
 
-test_that("ecx_val warnings behave as expected", {
-  expect_error(nsec(manec_example, ecx_val = 0.9))
-  expect_error(nsec(nec4param, ecx_val = 0.9))
-})
-
 test_that(paste0("nsec returns expected object types and precision is",
                  " passing correctly"), {
   nsec_summary <- nsec(manec_example, sig_val = 0.01, precision = 50) %>%
@@ -51,14 +46,14 @@ test_that(paste0("nsec returns expected object types and precision is",
 test_that("works for bayesnecfit", {
   nsec1 <- nsec(ecx4param)
   expect_equal(length(nsec1), 3)
-  expect_equal(names(nsec1), c("ec_0.01_Q50", "ec_0.01_Q2.5", "ec_0.01_Q97.5"))
+  expect_equal(names(nsec1), c("Q50", "Q2.5", "Q97.5"))
 })
 
 test_that("works for bayesmanecfit", {
   nsec1 <- nsec(manec_example) %>%
     suppressWarnings
   expect_equal(length(nsec1), 3)
-  expect_equal(names(nsec1), c("ec_0.01", "ec_0.01_lw", "ec_0.01_up"))
+  expect_equal(names(nsec1), c("Q50", "Q2.5", "Q97.5"))
 })
 
 test_that("xform passes correctly", {
@@ -73,11 +68,11 @@ test_that("posterior passes correctly", {
 })
 
 test_that("prob_vals passes correctly", {
-  nsec4 <- nsec(ecx4param, prob_vals = c(0.3, 0.5, 0.7))
-  expect_equal(names(nsec4), c("ec_0.01_Q30", "ec_0.01_Q50", "ec_0.01_Q70"))
+  nsec4 <- nsec(ecx4param, prob_vals = c(0.5, 0.3, 0.7))
+  expect_equal(names(nsec4), c("Q50", "Q30", "Q70"))
 })
 
 test_that("sig_val passes correctly", {
-  nsec4 <- nsec(ecx4param, prob_vals = c(0.3, 0.5, 0.7), sig_val = 0.05)
-  expect_equal(names(nsec4), c("ec_0.05_Q30", "ec_0.05_Q50", "ec_0.05_Q70"))
+  nsec4 <- nsec(ecx4param, prob_vals = c(0.5, 0.3, 0.7), sig_val = 0.05)
+  expect_equal(names(nsec4), c("Q50", "Q30", "Q70"))
 })
